@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2019 Sean Davis <bluesabre@xfce.org>
+#   Copyright (C) 2012-2020 Sean Davis <bluesabre@xfce.org>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -16,18 +16,17 @@
 #   You should have received a copy of the GNU General Public License along
 #   with this program.  If not, see <https://www.gnu.org/licenses/>.
 
+# pylint: disable=C0413
+
 """Helpers for an Ubuntu application."""
 import logging
 import os
 import sys
 
 import gi
-gi.require_version('GLib', '2.0')
-gi.require_version('GObject', '2.0')
-gi.require_version('Gdk', '3.0')
-gi.require_version('Gtk', '3.0')
-
-from gi.repository import GLib, GObject, Gdk, Gtk
+gi.require_version('GObject', '2.0')  # noqa
+gi.require_version('Gtk', '3.0')  # noqa
+from gi.repository import GObject, Gtk
 
 from . catfishconfig import get_data_file
 from . Builder import Builder
@@ -54,6 +53,44 @@ def check_gobject_version(major_version, minor_version, micro=0):
     return gobject_version >= (major_version, minor_version, micro)
 
 
+# Define a context manager to suppress stdout and stderr.
+class suppress_stdout_stderr(object):
+    '''
+    A context manager for doing a "deep suppression" of stdout and stderr in
+    Python, i.e. will suppress all print, even if the print originates in a
+    compiled C/Fortran sub-function.
+       This will not suppress raised exceptions, since exceptions are printed
+    to stderr just before a script exits, and after the context manager has
+    exited (at least, I think that is why it lets exceptions through).
+
+    From: Stack Overflow
+    Question: https://stackoverflow.com/questions/11130156/suppress-stdout-stderr-print-from-python-functions
+    Answer: https://stackoverflow.com/q/11130156
+    Author: jeremiahbuddha (https://stackoverflow.com/users/772487/jeremiahbuddha)
+    License: CC-BY-SA 3.0 (https://stackoverflow.com/help/licensing,
+                           https://creativecommons.org/licenses/by-sa/3.0/)
+    '''
+
+    def __init__(self):
+        # Open a pair of null files
+        self.null_fds = [os.open(os.devnull, os.O_RDWR) for x in range(2)]
+        # Save the actual stdout (1) and stderr (2) file descriptors.
+        self.save_fds = [os.dup(1), os.dup(2)]
+
+    def __enter__(self):
+        # Assign the null pointers to stdout and stderr.
+        os.dup2(self.null_fds[0], 1)
+        os.dup2(self.null_fds[1], 2)
+
+    def __exit__(self, *_):
+        # Re-assign the real stdout/stderr back to (1) and (2)
+        os.dup2(self.save_fds[0], 1)
+        os.dup2(self.save_fds[1], 2)
+        # Close all file descriptors
+        for fd in self.null_fds + self.save_fds:
+            os.close(fd)
+
+
 def get_builder(builder_file_name):
     """Return a fully-instantiated Gtk.Builder instance from specified ui file
 
@@ -67,7 +104,10 @@ def get_builder(builder_file_name):
 
     builder = Builder()
     builder.set_translation_domain('catfish')
-    builder.add_from_file(ui_filename)
+
+    with suppress_stdout_stderr():
+        builder.add_from_file(ui_filename)
+
     return builder
 
 
@@ -141,7 +181,6 @@ def get_help_uri(page=None):
 
 def show_uri(parent, link):
     """Open the specified URI."""
-    from gi.repository import Gtk  # pylint: disable=E0611
     screen = parent.get_screen()
     Gtk.show_uri(screen, link, Gtk.get_current_event_time())
 
@@ -155,20 +194,3 @@ def alias(alternative_function_name):
         function.aliases.append(alternative_function_name)
         return function
     return decorator
-
-
-def check_x11_session():
-    '''Is it an X.org session?'''
-    backend_env = GLib.environ_getenv(GLib.get_environ(), 'GDK_BACKEND')
-    if backend_env is None:
-        # We look for default display
-        display = Gdk.Display.get_default().get_name()
-        if display.startswith('wayland'):
-            return False
-        else:
-            return True
-    else:
-        if backend_env.lower() == 'x11':
-            return True
-        else:
-            return False
